@@ -1,20 +1,21 @@
 from dataclasses import dataclass
 from typing import Optional, List, Union
-from edgescan.data.types.object import Object
 
-import hodgepodge.time
+import edgescan.time
 import datetime
 
+from edgescan.type_hints import TIME
+
 
 @dataclass(frozen=True)
-class Assessment(Object):
+class Assessment:
     id: int
     type: str
     status: str
     created_at: datetime.datetime
 
     @property
-    def create_time(self) -> datetime.datetime:
+    def create_time(self) -> TIME:
         return self.created_at
 
     def matches(
@@ -39,7 +40,7 @@ class Assessment(Object):
 
         #: Filter assessments based on when they were last performed.
         if (min_create_time or max_create_time) and \
-                not hodgepodge.time.in_range(self.create_time, minimum=min_create_time, maximum=max_create_time):
+                not edgescan.time.in_range(self.create_time, min_create_time, max_create_time):
             return False
         return True
 
